return {
  fields = {
    box_once = {
      fields = {
        ["box.once"] = {
          argsDisplay = "key, function[, ...]",
          description = "Execute a function, provided it has not been executed before. A passed value\n    is checked to see whether the function has already been executed. If it has\n    been executed before, nothing happens. If it has not been executed before,\n    the function is invoked.\n\n    See an example of using ``box.once()`` while\n    `bootstrapping a replica set`.\n\n    If an error occurs inside ``box.once()`` when initializing a database, you\n    can re-execute the failed ``box.once()`` block without stopping the database.\n    The solution is to delete the ``once`` object from the system space\n    `_schema`.\n    Say ``box.space._schema:select{}``, find your ``once`` object there and\n    delete it. For example, re-executing a block with ``key='hello'`` :\n\n    When ``box.once()`` is used for initialization, it may be useful to\n    wait until the database is in an appropriate state (read-only or read-write).\n    In that case, see the functions in the `box.ctl submodule`.\n\n    ```lua\n        tarantool> box.space._schema:select{}\n        ---\n        - - ['cluster', 'b4e15788-d962-4442-892e-d6c1dd5d13f2']\n          - ['max_id', 512]\n          - ['oncebye']\n          - ['oncehello']\n          - ['version', 1, 7, 2]\n        ...\n```\n\n        tarantool> box.space._schema:delete('oncehello')\n        ---\n        - ['oncehello']\n        ...\n\n        tarantool> box.once('hello', function() end)\n        ---\n        ...",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}