return {
  fields = {
    csv = {
      fields = {
        csv = {
          description = "\n===============================================================================\n                                   Overview\n===============================================================================\n\nThe ``csv`` module handles records formatted according to Comma-Separated-Values\n(CSV) rules.\n\nThe default formatting rules are:\n\n* Lua `escape sequences`_ such as \\\\n or \\\\10 are legal within strings but not\n  within files,\n* Commas designate end-of-field,\n* Line feeds, or line feeds plus carriage returns, designate end-of-record,\n* Leading or trailing spaces are ignored,\n* Quote marks may enclose fields or parts of fields,\n* When enclosed by quote marks, commas and line feeds and spaces are treated\n  as ordinary characters, and a pair of quote marks \"\" is treated as a single\n  quote mark.\n\n.. _csv-options:\n\nThe possible options which can be passed to csv functions are:\n\n* :samp:`delimiter = {string}` (default: comma) -- single-byte character to\n  designate end-of-field\n* :samp:`quote_char = {string}` (default: quote mark) -- single-byte character\n  to designate encloser of string\n* :samp:`chunk_size = {number}` (default: 4096) -- number of characters to read\n  at once (usually for file-IO efficiency)\n* :samp:`skip_head_lines = {number}` (default: 0) -- number of lines to skip at\n  the start (usually for a header)\n\n===============================================================================\n                                    Index\n===============================================================================\n\nBelow is a list of all ``csv`` functions.\n\n.. container:: table\n\n    .. rst-class:: left-align-column-1\n    .. rst-class:: left-align-column-2\n\n    +--------------------------------------+---------------------------------+\n    | Name                                 | Use                             |\n    +======================================+=================================+\n    | `csv.load()                     | Load a CSV file                 |\n    |`                          |                                 |\n    +--------------------------------------+---------------------------------+\n    | `csv.dump()                     | Transform input into a          |\n    |`                          | CSV-formatted string            |\n    +--------------------------------------+---------------------------------+\n    | `csv.iterate()                  | Iterate over CSV records        |\n    |`                       |                                 |\n    +--------------------------------------+---------------------------------+\n\n.. _csv-load:\n\n",
          type = "module"
        },
        dump = {
          argsDisplay = "csv-table[, options, writable]",
          description = "Get table input from ``csv-table`` and return a CSV-formatted string as\n    output. Or, get table input from ``csv-table`` and put the output in\n    ``writable``. Usually :samp:`{options}` is not specified. Usually\n    ``writable``, if specified, is a file opened for writing. `csv.dump()\n   ` is the reverse of `csv.load()`.\n\n    :param table csv-table: a table which can be formatted according to the CSV\n                            rules.\n    :param table   options: optional. see `above`\n    :param object writable: any object which has a ``write()`` method",
          detail = "Transform input into a CSV-formatted string",
          type = "function"
        },
        iterate = {
          argsDisplay = "input, {options}",
          description = "Form a Lua iterator function for going through CSV records one field at a\n    time. Use of an iterator is strongly recommended if the amount of data is\n    large (ten or more megabytes).\n\n    :param table csv-table: a table which can be formatted according to the CSV\n                            rules.\n    :param table   options: see `above`\n\n    :return: Lua iterator function\n    :rtype:  iterator function\n\n    **Example:**",
          detail = "Iterate over CSV records",
          type = "function"
        },
        load = {
          argsDisplay = "readable[, {options}]",
          description = "Get CSV-formatted input from ``readable`` and return a table as output.\n    Usually ``readable`` is either a string or a file opened for reading.\n    Usually :samp:`{options}` is not specified.",
          detail = "Load a CSV file",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}