return {
  fields = {
    fiber = {
      fields = {
        channel = {
          argsDisplay = "[capacity]",
          description = "Create a new communication channel.\n\n    :param int capacity: the maximum number of slots (spaces for\n                         ``channel:put`` messages) that can be in use at once.\n                         The default is 0.\n\n    :return: new channel.\n    :rtype:  userdata, possibly including the string \"channel ...\".\n\n.. class:: channel_object\n\n    .. _channel_object-put:\n\n    .. method:: put(message[, timeout])\n\n        Send a message using a channel. If the channel is full,\n        ``channel:put()`` waits until there is a free slot in the channel.\n\n        :param lua-value message: what will be sent, usually a string or number or table\n        :param number timeout: maximum number of seconds to wait for a slot to become free\n        :return: If timeout is specified, and there is no free slot in the\n                 channel for the duration of the timeout, then the return value\n                 is ``false``. If the channel is closed, then the return value is ``false``.\n                 Otherwise, the return value is ``true``, indicating success.\n        :rtype:  boolean\n\n    .. _channel_object-close:\n\n    .. method:: close()\n\n        Close the channel. All waiters in the channel will stop waiting. All\n        following ``channel:get()`` operations will return ``nil``, and all\n        following ``channel:put()`` operations will return ``false``.\n\n    .. _channel_object-get:\n\n    .. method:: get([timeout])\n\n        Fetch and remove a message from a channel. If the channel is empty,\n        ``channel:get()`` waits for a message.\n\n        :param number timeout: maximum number of seconds to wait for a message\n        :return: If timeout is specified, and there is no message in the\n                 channel for the duration of the timeout, then the return\n                 value is ``nil``. If the channel is closed, then the\n                 return value is ``nil``. Otherwise, the return value is\n                 the message placed on the channel by ``channel:put()``.\n        :rtype:  usually string or number or table, as determined by ``channel:put``\n\n    .. _channel_object-is_empty:\n\n    .. method:: is_empty()\n\n        Check whether the channel is empty (has no messages).\n\n        :return: ``true`` if the channel is empty. Otherwise ``false``.\n        :rtype:  boolean\n\n    .. _channel_object-count:\n\n    .. method:: count()\n\n        Find out how many messages are in the channel.\n\n        :return: the number of messages.\n        :rtype:  number\n\n    .. _channel_object-is_full:\n\n    .. method:: is_full()\n\n        Check whether the channel is full.\n\n        :return: ``true`` if the channel is full (the number of messages\n                 in the channel equals the number of slots so there is no room for a new\n                 message). Otherwise ``false``.\n        :rtype:  boolean\n\n    .. _channel_object-has_readers:\n\n    .. method:: has_readers()\n\n        Check whether readers are waiting for a message because they\n        have issued ``channel:get()`` and the channel is empty.\n\n        :return: ``true`` if readers are waiting. Otherwise ``false``.\n        :rtype:  boolean\n\n    .. _channel_object-has_writers:\n\n    .. method:: has_writers()\n\n        Check whether writers are waiting\n        because they have issued ``channel:put()`` and the channel is full.\n\n        :return: ``true`` if writers are waiting. Otherwise ``false``.\n        :rtype:  boolean\n\n    .. _channel_object-is_closed:\n\n    .. method:: is_closed()",
          detail = "Create a communication channel",
          type = "function"
        },
        channel_object = {
          detail = "Check if a channel is closed",
          type = "function"
        },
        cond = {
          argsDisplay = "",
          description = "Create a new condition variable.\n\n    :return: new condition variable.\n    :rtype:  Lua object\n\n.. class:: cond_object\n\n    .. _cond_object-wait:\n\n    .. method:: wait([timeout])\n\n        Make the current fiber go to sleep, waiting until another fiber\n        invokes the ``signal()`` or ``broadcast()`` method on the cond object.\n        The sleep causes an implicit `fiber.yield()`.\n\n        :param timeout: number of seconds to wait, default = forever.\n        :return: If timeout is provided, and a signal doesn't happen for the\n                 duration of the timeout, ``wait()`` returns false. If a signal\n                 or broadcast happens, ``wait()`` returns true.\n        :rtype:  boolean\n\n    .. _cond_object-signal:\n\n    .. method:: signal()\n\n        Wake up a single fiber that has executed ``wait()`` for the same\n        variable.\n\n        :rtype:  nil\n\n    .. _cond_object-broadcast:\n\n    .. method:: broadcast()\n\n        Wake up all fibers that have executed ``wait()`` for the same variable.",
          detail = "Create a condition variable",
          type = "function"
        },
        cond_object = {
          detail = "Wake up all fibers",
          type = "function"
        },
        create = {
          argsDisplay = "function [, function-arguments]",
          description = "Create and start a fiber. The fiber is created and begins to run immediately.\n\n    :param function: the function to be associated with the fiber\n    :param function-arguments: what will be passed to function",
          detail = "Create and start a fiber",
          type = "function"
        },
        fiber = {
          description = "\n.. _fiber-create:\n\n",
          type = "module"
        },
        find = {
          argsDisplay = "id",
          description = ":param id: numeric identifier of the fiber.",
          detail = "Get a fiber object by ID",
          type = "function"
        },
        info = {
          argsDisplay = "",
          description = "Return information about all fibers.",
          detail = "Get information about all fibers",
          type = "function"
        },
        kill = {
          argsDisplay = "id",
          description = "Locate a fiber by its numeric id and cancel it. In other words,\n    `fiber.kill()` combines `fiber.find()` and\n    `fiber_object:cancel()`.",
          detail = "Cancel a fiber",
          type = "function"
        },
        new = {
          argsDisplay = "function [, function-arguments]",
          description = "Create but do not start a fiber: the fiber is created but does not\n    begin to run immediately -- it starts after the fiber creator\n    (that is, the job that is calling ``fiber.new()``) yields,\n    under `transaction control`.\n    The initial fiber state is 'suspended'.\n    Thus ``fiber.new()`` differs slightly from\n    `fiber.create()`.\n\n    Ordinarily ``fiber.new()`` is used in conjunction with\n    `fiber_object:set_joinable()`\n    and\n    `fiber_object:join()`.\n\n    :param function: the function to be associated with the fiber\n    :param function-arguments: what will be passed to function",
          detail = "Create but do not start a fiber",
          type = "function"
        },
        object = {
          detail = "Wait for a fiber's state to become 'dead'",
          type = "function"
        },
        ["object.storage"] = {
          detail = "Local storage within the fiber",
          type = "function"
        },
        self = {
          argsDisplay = "",
          description = ":Return: fiber object for the currently scheduled fiber.\n    :Rtype: userdata\n\n    **Example:**\n\n    ```lua\n        tarantool> fiber.self()\n        ---\n        - status: running\n          name: interactive\n          id: 101\n        ...\n```\n\n.. _fiber-find:\n\n.",
          detail = "Get a fiber object",
          type = "function"
        },
        sleep = {
          argsDisplay = "time",
          description = "Yield control to the scheduler and sleep for the specified number\n    of seconds. Only the current fiber can be made to sleep.",
          detail = "Make a fiber go to sleep",
          type = "function"
        },
        status = {
          argsDisplay = "[fiber_object]",
          description = "Return the status of the current fiber.\n    Or, if optional fiber_object is passed, return the status of the\n    specified fiber.",
          detail = "Get the current fiber's status",
          type = "function"
        },
        testcancel = {
          argsDisplay = "",
          description = "Check if the current fiber has been cancelled\n    and throw an exception if this is the case.\n\n    .. NOTE::\n\n        Even if you catch the exception, the fiber will remain cancelled.\n        Most types of calls will check ``fiber.testcancel()``.\n        However, some functions (``id``, ``status``, ``join`` etc.) will return no error.\n        We recommend application developers to implement occasional checks with\n        `fiber.testcancel()` and to end fiber's execution\n        as soon as possible in case it has been cancelled.\n\n    **Example:**\n\n    ```lua\n        tarantool> fiber.testcancel()\n        ---\n        - error: fiber is cancelled\n        ...\n```\n\n.. class:: fiber_object\n\n    .. _fiber_object-id:\n\n    .. method:: id()\n\n        :param fiber_object: generally this is an object referenced in the return\n                             from `fiber.create`\n                             or `fiber.self`\n                             or `fiber.find`\n        :Return: id of the fiber.\n        :Rtype: number\n\n        ``fiber.self():id()`` can also be expressed as ``fiber.id()``.\n\n        **Example:**\n\n        ```lua\n            tarantool> fiber_object = fiber.self()\n            ---\n            ...\n            tarantool> fiber_object:id()\n            ---\n            - 101\n            ...\n```\n\n    .. _fiber_object-name_get:\n\n    .. method:: name()\n\n        :param fiber_object: generally this is an object referenced in the return\n                             from `fiber.create`\n                             or `fiber.self`\n                             or `fiber.find`\n        :Return: name of the fiber.\n        :Rtype: string\n\n        ``fiber.self():name()`` can also be expressed as ``fiber.name()``.\n\n        **Example:**\n\n        ```lua\n            tarantool> fiber.self():name()\n            ---\n            - interactive\n            ...\n```\n\n    .. _fiber_object-name_set:\n\n    .. method:: name(name)\n\n        Change the fiber name. By default a Tarantool server's\n        interactive-mode fiber is named 'interactive' and new\n        fibers created due to `fiber.create` are named 'lua'.\n        Giving fibers distinct names makes it easier to\n        distinguish them when using `fiber.info`.\n\n        :param fiber_object: generally this is an object referenced in the return\n                             from `fiber.create`\n                             or `fiber.self`\n                             or `fiber.find`\n        :param string name: the new name of the fiber.\n\n        :Return: nil\n\n        **Example:**\n\n        ```lua\n            tarantool> fiber.self():name('non-interactive')\n            ---\n            ...\n```\n\n    .. _fiber_object-status:\n\n    .. method:: status()\n\n        Return the status of the specified fiber.\n\n        :param fiber_object: generally this is an object referenced in the return\n                             from `fiber.create`\n                             or `fiber.self`\n                             or `fiber.find`\n        :Return: the status of fiber. One of: “dead”, “suspended”, or “running”.\n        :Rtype: string\n\n        ``fiber.self():status(`` can also be expressed as ``fiber.status()``.\n\n        **Example:**\n\n        ```lua\n            tarantool> fiber.self():status()\n            ---\n            - running\n            ...\n```\n\n    .. _fiber_object-cancel:\n\n    .. method:: cancel()\n\n        Cancel a fiber. Running and suspended fibers can be cancelled.\n        After a fiber has been cancelled, attempts to operate on it will\n        cause errors, for example `fiber_object:name()`\n        will cause ``error: the fiber is dead``. But a dead fiber can still\n        report its id and status.\n\n        :param fiber_object: generally this is an object referenced in the return\n                             from `fiber.create`\n                             or `fiber.self`\n                             or `fiber.find`\n        :Return: nil\n\n        Possible errors: cancel is not permitted for the specified fiber object.\n\n        **Example:**\n\n        ```lua\n            tarantool> fiber.self():cancel() -- kill self, may make program end\n            ---\n            ...\n            tarantool> fiber.self():cancel()\n            ---\n            - error: fiber is cancelled\n            ...\n            tarantool> fiber.self:id()\n            ---\n            - 163\n            ...\n            tarantool> fiber.self:status()\n            ---\n            - dead\n            ...\n```\n\n    .. _fiber_object-storage:\n\n    .. data:: storage\n\n        Local storage within the fiber. The storage can contain any number of\n        named values, subject to memory limitations. Naming may be done with\n        :samp:`{fiber_object}.storage.{name}` or :samp:`{fiber_object}.storage['{name}'].`\n        or with a number :samp:`{fiber_object}.storage[{number}]`.\n        Values may be either numbers or strings. The Lua garbage collector will\n        mark or free the local storage when :samp:`{fiber_object}:cancel()` happens.\n\n        **Example:**\n\n        ```lua\n            tarantool> fiber = require('fiber')\n            ---\n            ...\n            tarantool> function f () fiber.sleep(1000); end\n            ---\n            ...\n            tarantool> fiber_function = fiber.create(f)\n            ---\n            ...\n            tarantool> fiber_function.storage.str1 = 'string'\n            ---\n            ...\n            tarantool> fiber_function.storage['str1']\n            ---\n            - string\n            ...\n            tarantool> fiber_function:cancel()\n            ---\n            ...\n            tarantool> fiber_function.storage['str1']\n            ---\n            - error: '[string \"return fiber_function.storage[''str1'']\"]:1: the fiber is dead'\n            ...\n```\n\n        See also `box.session.storage`.\n\n    .. _fiber_object-set_joinable:\n\n    .. method:: set_joinable(true_or_false)\n\n        ``fiber_object:set_joinable(true)`` makes a fiber joinable;\n        ``fiber_object:set_joinable(false)`` makes a fiber not joinable;\n        the default is false.\n\n        A joinable fiber can be waited for, with\n        `fiber_object:join()`.\n\n        Best practice is to call ``fiber_object:set_joinable()`` before the\n        fiber function begins to execute, because otherwise the fiber could\n        become 'dead' before ``fiber_object:set_joinable()`` takes effect.\n        The usual sequence could be:\n\n        1. Call ``fiber.new()`` instead of ``fiber.create()`` to create a new\n           fiber_object.\n\n           Do not yield at this point, because that will cause the fiber\n           function to begin.\n\n        2. Call ``fiber_object:set_joinable(true)`` to make the new\n           fiber_object joinable.\n\n           Now it is safe to yield.\n\n        3. Call ``fiber_object:join()``.\n\n           Usually ``fiber_object:join()`` should be called, otherwise the\n           fiber's status may become 'suspended' when the fiber function ends,\n           instead of 'dead'.\n\n        :param true_or_false: the boolean value that changes the ``set_joinable``\n                              flag\n\n        :Return: nil\n\n        **Example:**\n\n        The result of the following sequence of requests is:\n\n        * the global variable ``d`` will be 6 (which proves that the function\n          was not executed until after ``d`` was set to 1, when\n          ``fiber.sleep(1)`` caused a yield);\n        * ``fiber.status(fi2)`` will be 'suspended' (which proves that after\n          the function was executed the fiber status did not change to 'dead').\n\n        ```lua\n            fiber=require('fiber')\n            d=0\n            function fu2() d=d+5 end\n            fi2=fiber.new(fu2) fi2:set_joinable(true) d=1 fiber.sleep(1)\n            print(d)\n            fiber.status(fi2)\n```\n\n    .. _fiber_object-join:\n\n    .. method:: join()\n\n        \"Join\" a joinable fiber.\n        That is, let the fiber's function run and wait\n        until the fiber's status is 'dead' (normally a status\n        becomes 'dead' when the function execution finishes).\n        Joining will cause a yield, therefore, if the fiber is\n        currently in a suspended state, execution of its fiber\n        function will resume.\n\n        This kind of waiting is more convenient than going into\n        a loop and periodically checking the status; however,\n        it works only if the fiber was created with\n        `fiber.new()`\n        and was made joinable with\n        `fiber_object:set_joinable()`.\n\n        :Return: two values. The first value is boolean.\n                 If the first value is true, then the join succeeded\n                 because the fiber's function ended normally and the\n                 second result has the return value from the fiber's function.\n                 If the first value is false, then the join succeeded\n                 because the fiber's function ended abnormally and the\n                 second result has the details about the error, which\n                 one can unpack in the same way that one unpacks\n                 `a pcall result`.",
          detail = "Check if the current fiber has been cancelled",
          type = "function"
        },
        time = {
          argsDisplay = "",
          description = ":Return: current system time (in seconds since the epoch) as a Lua\n             number. The time is taken from the event loop clock,\n             which makes this call very cheap, but still useful for\n             constructing artificial tuple keys.\n    :Rtype: num\n\n    **Example:**\n\n        ```lua\n            tarantool> fiber.time(), fiber.time()\n            ---\n            - 1448466279.2415\n            - 1448466279.2415\n            ...\n```\n\n.. _fiber-time64:\n\n.",
          detail = "Get the system time in seconds",
          type = "function"
        },
        time64 = {
          argsDisplay = "",
          description = ":Return: current system time (in microseconds since the epoch)\n             as a 64-bit integer. The time is taken from the event\n             loop clock.\n    :Rtype: num\n\n    **Example:**\n\n    ```lua\n            tarantool> fiber.time(), fiber.time64()\n            ---\n            - 1448466351.2708\n            - 1448466351270762\n            ...\n```\n\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\nExample\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nMake the function which will be associated with the fiber. This function\ncontains an infinite loop. Each iteration\nof the loop adds 1 to a global variable named gvar, then goes to sleep for\n2 seconds. The sleep causes an implicit `fiber.yield()`.\n\n```lua\n    tarantool> fiber = require('fiber')\n    tarantool> function function_x()\n             >   gvar = 0\n             >   while true do\n             >     gvar = gvar + 1\n             >     fiber.sleep(2)\n             >   end\n             > end\n    ---\n    ...\n```\n\nMake a fiber, associate function_x with the fiber, and start function_x.\nIt will immediately \"detach\" so it will be running independently of the caller.\n\n```lua\n    tarantool> gvar = 0\n```\n\n    tarantool> fiber_of_x = fiber.create(function_x)\n    ---\n    ...\n\nGet the id of the fiber (fid), to be used in later displays.\n\n```lua\n    tarantool> fid = fiber_of_x:id()\n    ---\n    ...\n```\n\nPause for a while, while the detached function runs. Then ... Display the fiber\nid, the fiber status, and gvar (gvar will have gone up a bit depending how long\nthe pause lasted). The status is suspended because the fiber spends almost all\nits time sleeping or yielding.\n\n```lua\n    tarantool> print('#', fid, '. ', fiber_of_x:status(), '. gvar=', gvar)\n    # 102 .  suspended . gvar= 399\n    ---\n    ...\n```\n\nPause for a while, while the detached function runs. Then ... Cancel the fiber.\nThen, once again ... Display the fiber id, the fiber status, and gvar (gvar\nwill have gone up a bit more depending how long the pause lasted). This time\nthe status is dead because the cancel worked.\n\n```lua\n    tarantool> fiber_of_x:cancel()\n    ---\n    ...\n    tarantool> print('#', fid, '. ', fiber_of_x:status(), '. gvar=', gvar)\n    # 102 .  dead . gvar= 421\n    ---\n    ...\n```\n\n.. _coroutine:  http://www.lua.org/pil/contents.html#9\n\n.. _fiber_ipc-channel:\n\n=================================================\nChannels\n=================================================\n\nCall ``fiber.channel()`` to allocate space and get a channel object, which will\nbe called channel for examples in this section.\n\nCall the other routines, via channel, to send messages, receive messages, or\ncheck channel status.\n\nMessage exchange is synchronous. The Lua garbage collector will mark or free the\nchannel when no one is\nusing it, as with any other Lua object. Use object-oriented syntax, for example\n``channel:put(message)`` rather than ``fiber.channel.put(message)``.\n\n.. _fiber-channel:\n\n.",
          detail = "Get the system time in microseconds",
          type = "function"
        },
        yield = {
          argsDisplay = "",
          description = "Yield control to the scheduler. Equivalent to `fiber.sleep(0)`,\n    except that `fiber.sleep(0)` depends on a timer, `fiber.yield()` does not.\n\n    **Example:**\n\n    ```lua\n        tarantool> fiber.yield()\n        ---\n        ...\n```\n\n.. _fiber-status:\n\n.",
          detail = "Yield control",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}