return {
  fields = {
    osmodule = {
      fields = {
        clock = {
          argsDisplay = "",
          description = "Return the number of CPU seconds since the program start.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.clock()\n        ---\n        - 0.05\n        ...\n```\n\n.. _os-tmpname:\n\n.",
          detail = "Get the number of CPU seconds since the program start",
          type = "function"
        },
        date = {
          argsDisplay = "format-string[, time-since-epoch]",
          description = "Return a formatted date.\n\n    Parameters: (string) format-string = instructions; (string) time-since-epoch =\n    number of seconds since 1970-01-01. If time-since-epoch is omitted, it is assumed to be the current time.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.date(\"%A %B %d\")\n        ---\n        - Sunday April 24\n        ...\n```\n\n.. _os-exit:\n\n.",
          detail = "Get a formatted date",
          type = "function"
        },
        difftime = {
          argsDisplay = "time1, time2",
          description = "Return the number of seconds between two times.\n\n    **Example:**\n\n    .. code-block:: tarantoolsession\n\n        tarantool> os.difftime(os.time() - 0)\n        ---\n        - 1486594859\n        ...",
          detail = "Get the number of seconds between two times",
          type = "function"
        },
        environ = {
          argsDisplay = "",
          description = "Return a table containing all environment variables.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.environ()['TERM']..os.environ()['SHELL']\n        ---\n        - xterm/bin/bash\n        ...\n```\n\n.. _os-setenv:\n\n.",
          detail = "Get a table with all environment variables",
          type = "function"
        },
        execute = {
          argsDisplay = "shell-command",
          description = "Execute by passing to the shell.",
          detail = "Execute by passing to the shell",
          type = "function"
        },
        exit = {
          argsDisplay = "",
          description = "Exit the program. If this is done on a server instance, then the instance stops.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.exit()\n        user@user-shell:~/tarantool_sandbox$\n```\n\n.. _os-time:\n\n.",
          detail = "Exit the program",
          type = "function"
        },
        getenv = {
          argsDisplay = "variable-name",
          description = "Get environment variable.\n\n    Parameters: (string) variable-name = environment variable name.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.getenv('PATH')\n        ---\n        - /usr/local/sbin:/usr/local/bin:/usr/sbin\n        ...\n```\n\n.. _os-remove:\n\n.",
          detail = "Get an environment variable",
          type = "function"
        },
        os = {
          description = "\n===============================================================================\n                                   Overview\n===============================================================================\n\nThe ``os`` module contains the functions `execute()`,\n`rename()`, `getenv()`,\n`remove()`, `date()`,\n`exit()`, `time()`,\n`clock()`, `tmpname()`,\n`environ()`,\n`setenv()`,\n`setlocale()`,\n`difftime()`.\nMost of these functions are described in the Lua manual\nChapter 22 `The Operating System Library\n<https://www.lua.org/pil/contents.html#22>`_.\n\n===============================================================================\n                                    Index\n===============================================================================\n\nBelow is a list of all ``os`` functions.\n\n.. container:: table\n\n    .. rst-class:: left-align-column-1\n    .. rst-class:: left-align-column-2\n\n    +--------------------------------------+---------------------------------+\n    | Name                                 | Use                             |\n    +======================================+=================================+\n    | `os.execute()                   | Execute by passing to the shell |\n    |`                        |                                 |\n    +--------------------------------------+---------------------------------+\n    | `os.rename()                    | Rename a file or directory      |\n    |`                         |                                 |\n    +--------------------------------------+---------------------------------+\n    | `os.getenv()                    | Get an environment variable     |\n    |`                         |                                 |\n    +--------------------------------------+---------------------------------+\n    | `os.remove()                    | Remove a file or directory      |\n    |`                         |                                 |\n    +--------------------------------------+---------------------------------+\n    | `os.date()                      | Get a formatted date            |\n    |`                           |                                 |\n    +--------------------------------------+---------------------------------+\n    | `os.exit()                      | Exit the program                |\n    |`                           |                                 |\n    +--------------------------------------+---------------------------------+\n    | `os.time()                      | Get the number of seconds since |\n    |`                           | the epoch                       |\n    +--------------------------------------+---------------------------------+\n    | `os.clock()                     | Get the number of CPU seconds   |\n    |`                          | since the program start         |\n    +--------------------------------------+---------------------------------+\n    | `os.tmpname()                   | Get the name of a temporary     |\n    |`                        | file                            |\n    +--------------------------------------+---------------------------------+\n    | `os.environ()                   | Get a table with all            |\n    |`                        | environment variables           |\n    +--------------------------------------+---------------------------------+\n    | `os.setenv()                    | Set an environment variable     |\n    |`                         |                                 |\n    +--------------------------------------+---------------------------------+\n    | `os.setlocale()                 | Change the locale               |\n    |`                      |                                 |\n    +--------------------------------------+---------------------------------+\n    | `os.difftime()                  | Get the number of seconds       |\n    |`                       | between two times               |\n    +--------------------------------------+---------------------------------+\n\n.. _os-execute:\n\n",
          type = "module"
        },
        remove = {
          argsDisplay = "name",
          description = "Remove file or directory.\n\n    Parameters: (string) name = name of file or directory which will be removed.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.remove('file')\n        ---\n        - true\n        ...\n```\n\n.. _os-date:\n\n.",
          detail = "Remove a file or directory",
          type = "function"
        },
        rename = {
          argsDisplay = "old-name, new-name",
          description = "Rename a file or directory.",
          detail = "Rename a file or directory",
          type = "function"
        },
        setenv = {
          argsDisplay = "variable-name, variable-value",
          description = "Set an environment variable.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.setenv('VERSION','99')\n        ---\n        -\n        ...\n```\n\n.. _os-setlocale:\n\n.",
          detail = "Set an environment variable",
          type = "function"
        },
        setlocale = {
          argsDisplay = "[new-locale-string]",
          description = "Change the locale. If new-locale-string is\n    not specified, return the current locale.\n\n    **Example:**\n\n    ```lua\n        tarantool> require('string').sub(os.setlocale(),1,20)\n        ---\n        - LC_CTYPE=en_US.UTF-8\n        ...\n```\n\n.. _os-difftime:\n\n.",
          detail = "Change the locale",
          type = "function"
        },
        time = {
          argsDisplay = "",
          description = "Return the number of seconds since the epoch.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.time()\n        ---\n        - 1461516945\n        ...\n```\n\n.. _os-clock:\n\n.",
          detail = "Get the number of seconds since the epoch",
          type = "function"
        },
        tmpname = {
          argsDisplay = "",
          description = "Return a name for a temporary file.\n\n    **Example:**\n\n    ```lua\n        tarantool> os.tmpname()\n        ---\n        - /tmp/lua_7SW1m2\n        ...\n```\n\n.. _os-environ:\n\n.",
          detail = "Get the name of a temporary file",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}