return {
  fields = {
    socket = {
      fields = {
        [")"] = {
          detail = "Create a socket",
          type = "function"
        },
        __call = {
          argsDisplay = "domain, type, protocol",
          description = "Create a new TCP or UDP socket. The argument values\n    are the same as in the `Linux socket(2) man page <http://man7.org/linux/man-pages/man2/socket.2.html>`_.",
          type = "function"
        },
        getaddrinfo = {
          argsDisplay = "host, type, [, {option-list}]",
          description = "The ``socket.getaddrinfo()`` function is useful for finding information\n    about a remote site so that the correct arguments for\n    ``sock:sysconnect()`` can be passed.\n    This function may use the `worker_pool_threads`\n    configuration parameter.",
          detail = "Get information about a remote site",
          type = "function"
        },
        iowait = {
          argsDisplay = "fd, read-or-write-flags, [timeout]",
          description = "The ``socket.iowait()`` function is used to wait until read-or-write activity\n    occurs for a file descriptor.",
          detail = "Wait for read/write activity",
          type = "function"
        },
        object = {
          detail = "Get information about the connection's far side",
          type = "function"
        },
        socket = {
          description = "\n.. _socket-socket:\n\n",
          type = "module"
        },
        tcp_connect = {
          argsDisplay = "host[, port[, timeout]]",
          description = "Connect a socket to a remote host.",
          detail = "Connect a socket to a remote host",
          type = "function"
        },
        tcp_server = {
          argsDisplay = "host, port, handler-function-or-table [, timeout]",
          description = "The ``socket.tcp_server()`` function makes Tarantool act as a server that\n    can accept connections. Usually the same objective\n    is accomplished with `box.cfg{listen=...}`.\n\n    :param string         host: host name or IP\n    :param number         port: host port, may be 0\n    :param function/table handler-function-or-table: what to execute when a\n                                                     connection occurs\n    :param number         timeout: number of seconds to wait before\n                                   timing out\n\n    The handler-function-or-table parameter may be simply a function name\n    / function declaration:\n    :code:`handler_function`. Or it may be a table:\n    :code:`{handler =`\n    :samp:`{handler_function} [, prepare = {prepare_function}] [, name = {name}]`\n    :code:`}`.\n    ``handler_function`` is mandatory; it may have a\n    single parameter = the socket; it is for continuous\n    operation after the connection is made.\n    ``prepare_function`` is optional; it is executed once before\n    any connection is made. Examples:\n\n        ```none\n            socket.tcp_server('localhost', 3302, function (s) loop_loop() end)\n            socket.tcp_server('localhost', 3302, {handler=hfunc, name='name'})\n            socket.tcp_server('localhost', 3302, {handler=hfunc, prepare=pfunc})\n```\n\n    For a fuller example see\n    `Use tcp_server to accept file contents sent with socat`.\n\n.. class:: socket_object\n\n    .. _socket-sysconnect:\n\n    .. method:: sysconnect(host, port)\n\n        Connect an existing socket to a remote host. The argument values are the same as\n        in `tcp_connect()`.\n        The host must be an IP address.\n\n        Parameters:\n          * Either:\n             * host - a string representation of an IPv4 address\n               or an IPv6 address;\n             * port - a number.\n          * Or:\n             * host - a string containing \"unix/\";\n             * port - a string containing a path to a unix socket.\n          * Or:\n             * host - a number, 0 (zero), meaning \"all local\n               interfaces\";\n             * port - a number. If a port number is 0 (zero),\n               the socket will be bound to a random local port.\n\n\n        :return: the socket object value may change if sysconnect() succeeds.\n        :rtype:  boolean\n\n        **Example:**\n\n        ```none\n            socket = require('socket')\n            sock = socket('AF_INET', 'SOCK_STREAM', 'tcp')\n            sock:sysconnect(0, 3301)\n```\n\n    .. _socket-send:\n\n    .. method:: send(data)\n                write(data)\n\n        Send data over a connected socket.\n\n        :param string data: what is to be sent\n        :return: the number of bytes sent.\n        :rtype:  number\n\n        Possible errors: nil on error.\n\n    .. _socket-syswrite:\n\n    .. method:: syswrite(size)\n\n        Write as much data as possible to the socket buffer if non-blocking.\n        Rarely used. For details see `this description`_.\n\n    .. _socket-recv:\n\n    .. method:: recv(size)\n\n        Read ``size`` bytes from a connected socket. An internal read-ahead\n        buffer is used to reduce the cost of this call.\n\n        :param integer size: maximum number of bytes to receive. See `Recommended size`.\n        :return: a string of the requested length on success.\n        :rtype:  string\n\n        Possible errors: On error, returns an empty string, followed by status,\n        errno, errstr. In case the writing side has closed its\n        end, returns the remainder read from the socket (possibly\n        an empty string), followed by \"eof\" status.\n\n    .. _socket-read:\n\n    .. method:: read(limit [, timeout])\n                read(delimiter [, timeout])\n                read({options} [, timeout])\n\n        Read from a connected socket until some condition is true, and return\n        the bytes that were read.\n        Reading goes on until ``limit`` bytes have been read, or a delimiter\n        has been read, or a timeout has expired.\n        Unlike ``socket_object:recv`` (which uses an internal read-ahead buffer),\n        ``socket_object:read`` depends on the socket's buffer.\n\n        :param integer    limit: maximum number of bytes to read, for\n                                 example 50 means \"stop after 50 bytes\"\n        :param string delimiter: separator for example\n                                 '?' means \"stop after a question mark\"\n        :param number   timeout: maximum number of seconds to wait, for\n                                 example 50 means \"stop after 50 seconds\".\n        :param table    options: :samp:`chunk={limit}` and/or\n                                 :samp:`delimiter={delimiter}`,\n                                 for example :code:`{chunk=5,delimiter='x'}`.\n\n        :return: an empty string if there is nothing more to read, or a nil\n                 value if error, or a string up to ``limit`` bytes long,\n                 which may include the bytes that matched the ``delimiter``\n                 expression.\n        :rtype: string\n\n    .. _socket-sysread:\n\n    .. method:: sysread(size)\n\n        Return data from the socket buffer if non-blocking.\n        In case the socket is blocking, ``sysread()`` can block the calling process.\n        Rarely used. For details, see also\n        `this description <https://github.com/tarantool/tarantool/wiki/sockets%201.6>`_.\n\n        :param integer size: maximum number of bytes to read, for\n                             example 50 means \"stop after 50 bytes\"\n\n        :return: an empty string if there is nothing more to read, or a nil\n                 value if error, or a string up to ``size`` bytes long.\n        :rtype:  string\n\n    .. _socket-bind:\n\n    .. method:: bind(host [, port])\n\n        Bind a socket to the given host/port. A UDP socket after binding\n        can be used to receive data (see `socket_object.recvfrom`).\n        A TCP socket can be used to accept new connections, after it has\n        been put in listen mode.\n\n        :param string host: URL or IP address\n        :param number port: port number\n\n        :return: true for success, false for error.\n                 If return is false, use `socket_object:errno()`\n                 or `socket_object:error()` to see details.\n        :rtype:  boolean\n\n    .. _socket-listen:\n\n    .. method:: listen(backlog)\n\n        Start listening for incoming connections.\n\n        :param backlog: on Linux the listen ``backlog`` backlog may be from\n                        ``/proc/sys/net/core/somaxconn``, on BSD the backlog\n                        may be ``SOMAXCONN``.\n\n        :return: true for success, false for error.\n        :rtype: boolean.\n\n    .. _socket-accept:\n\n    .. method:: accept()\n\n        Accept a new client connection and create a new connected socket.\n        It is good practice to set the socket's blocking mode explicitly\n        after accepting.\n\n        :return: new socket if success.\n        :rtype: userdata\n\n        Possible errors: nil.\n\n    .. _socket-sendto:\n\n    .. method:: sendto(host, port, data)\n\n        Send a message on a UDP socket to a specified host.\n\n        :param string host: URL or IP address\n        :param number port: port number\n        :param string data: what is to be sent\n\n        :return: the number of bytes sent.\n        :rtype:  number\n\n        Possible errors: on error, returns nil and may return status, errno, errstr.\n\n    .. _socket-recvfrom:\n\n    .. method:: recvfrom(size)\n\n        Receive a message on a UDP socket.\n\n        :param integer size: maximum number of bytes to receive. See `Recommended size`.\n        :return: message, a table containing \"host\", \"family\" and \"port\" fields.\n        :rtype:  string, table\n\n        Possible errors: on error, returns status, errno, errstr.\n\n        **Example:**\n\n        After ``message_content, message_sender = recvfrom(1)``\n        the value of ``message_content`` might be a string containing 'X' and\n        the value of ``message_sender`` might be a table containing\n\n        ```none\n            message_sender.host = '18.44.0.1'\n            message_sender.family = 'AF_INET'\n            message_sender.port = 43065\n```\n\n    .. _socket-shutdown:\n\n    .. method:: shutdown(how)\n\n        Shutdown a reading end, a writing end, or both ends of a socket.\n\n        :param how: socket.SHUT_RD, socket.SHUT_WR, or socket.SHUT_RDWR.\n\n        :return: true or false.\n        :rtype:  boolean\n\n    .. _socket-close:\n\n    .. method:: close()\n\n        Close (destroy) a socket. A closed socket should not be used any more.\n        A socket is closed automatically when the Lua garbage collector removes\n        its user data.\n\n        :return: true on success, false on error. For example, if\n                 sock is already closed, sock:close() returns false.\n        :rtype:  boolean\n\n    .. _socket-error:\n\n    .. method:: error()\n                errno()\n\n        Retrieve information about the last error that occurred on a socket, if any.\n        Errors do not cause throwing of exceptions so these functions are usually necessary.\n\n        :return: result for ``sock:errno()``, result for ``sock:error()``.\n                 If there is no error, then ``sock:errno()`` will return 0 and ``sock:error()``.\n        :rtype:  number, string\n\n    .. _socket-setsockopt:\n\n    .. method:: setsockopt(level, name, value)\n\n        Set socket flags. The argument values are the same as in the\n        `Linux getsockopt(2) man page <http://man7.org/linux/man-pages/man2/setsockopt.2.html>`_.\n        The ones that Tarantool accepts are:\n\n            * SO_ACCEPTCONN\n            * SO_BINDTODEVICE\n            * SO_BROADCAST\n            * SO_DEBUG\n            * SO_DOMAIN\n            * SO_ERROR\n            * SO_DONTROUTE\n            * SO_KEEPALIVE\n            * SO_MARK\n            * SO_OOBINLINE\n            * SO_PASSCRED\n            * SO_PEERCRED\n            * SO_PRIORITY\n            * SO_PROTOCOL\n            * SO_RCVBUF\n            * SO_RCVBUFFORCE\n            * SO_RCVLOWAT\n            * SO_SNDLOWAT\n            * SO_RCVTIMEO\n            * SO_SNDTIMEO\n            * SO_REUSEADDR\n            * SO_SNDBUF\n            * SO_SNDBUFFORCE\n            * SO_TIMESTAMP\n            * SO_TYPE\n\n        Setting SO_LINGER is done with ``sock:linger(active)``.\n\n    .. _socket-getsockopt:\n\n    .. method:: getsockopt(level, name)\n\n        Get socket flags. For a list of possible flags see ``sock:setsockopt()``.\n\n    .. _socket-linger:\n\n    .. method:: linger([active])\n\n        Set or clear the SO_LINGER flag. For a description of the flag, see\n        the `Linux man page <http://man7.org/linux/man-pages/man1/loginctl.1.html>`_.\n\n        :param boolean active:\n\n        :return: new active and timeout values.\n\n    .. _socket-nonblock:\n\n    .. method:: nonblock([flag])\n\n        * ``sock:nonblock()`` returns the current flag value.\n        * ``sock:nonblock(false)`` sets the flag to false and returns false.\n        * ``sock:nonblock(true)`` sets the flag to true and returns true.\n\n        This function may be useful before invoking a function which might\n        otherwise block indefinitely.\n\n    .. _socket-readable:\n\n    .. method:: readable([timeout])\n\n        Wait until something is readable, or until a timeout value expires.\n\n        :return: true if the socket is now readable, false if timeout expired;\n\n    .. _socket-writable:\n\n    .. method:: writable([timeout])\n\n        Wait until something is writable, or until a timeout value expires.\n\n        :return: true if the socket is now writable, false if timeout expired;\n\n    .. _socket-wait:\n\n    .. method:: wait([timeout])\n\n        Wait until something is either readable or writable, or until a timeout value expires.\n\n        :return: 'R' if the socket is now readable, 'W' if the socket is now writable, 'RW' if the socket is now both readable and writable, '' (empty string) if timeout expired;\n\n    .. _socket-name:\n\n    .. method:: name()\n\n        The ``sock:name()`` function is used to get information about the\n        near side of the connection. If a socket was bound to ``xyz.com:45``,\n        then ``sock:name`` will return information about ``[host:xyz.com, port:45]``.\n        The equivalent POSIX function is ``getsockname()``.\n\n        :return: A table containing these fields: \"host\", \"family\", \"type\", \"protocol\", \"port\".\n        :rtype:  table\n\n    .. _socket-peer:\n\n    .. method:: peer()\n\n        The ``sock:peer()`` function is used to get information about the far side of a connection.\n        If a TCP connection has been made to a distant host ``tarantool.org:80``, ``sock:peer()``\n        will return information about ``[host:tarantool.org, port:80]``.\n        The equivalent POSIX function is ``getpeername()``.",
          detail = "Make Tarantool act as a TCP server",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}