return {
  fields = {
    table = {
      fields = {
        deepcopy = {
          argsDisplay = "input-table",
          description = "Return a \"deep\" copy of the table -- a copy which follows\n    nested structures to any depth and does not depend on pointers,\n    it copies the contents.\n\n    :param input-table: (table) the table to copy",
          type = "function"
        },
        sort = {
          argsDisplay = "input-table [, comparison-function]",
          description = "Put the input-table contents in sorted order.\n\n    The `basic Lua table.sort <https://www.lua.org/manual/5.1/manual.html#pdf-table.sort>`_\n    has a default comparison-function: :code:`function (a, b) return a < b end`.\n\n    That is efficient and standard. However, sometimes Tarantool users\n    will want an equivalent to ``table.sort`` which has any of these features:\n\n    (1) If the table contains nils, except nils at the end, the results must still be correct.\n    That is not the case with the default tarantool_sort, and it cannot\n    be fixed by making a comparison that checks whether a and b are nil.\n    (Before trying certain Internet suggestions, test with\n    {1, nil, 2, -1, 44, 1e308, nil, 2, nil, nil, 0}.\n\n    (2) If strings are to be sorted in a language-aware way, there must be a\n    parameter for collation.\n\n    (3) If the table has a mix of types, then they must be sorted as\n    booleans, then numbers, then strings, then byte arrays.\n\n    Since all those features are available in Tarantool spaces,\n    the solution for Tarantool is simple: make a temporary Tarantool\n    space, put the table contents into it, retrieve the tuples from it\n    in order, and overwrite the table.\n\n    Here then is ``tarantool_sort()`` which does the same thing as\n    ``table.sort`` but has those extra features. It is not fast and\n    it requires a database privilege, so it should only be used if the\n    extra features are necessary.\n\n    ```none\n        function tarantool_sort(input_table, collation)\n            local c = collation or 'binary'\n            local tmp_name = 'Temporary_for_tarantool_sort'\n            pcall(function() box.space[tmp_name]:drop() end)\n            box.schema.space.create(tmp_name, {temporary = true})\n            box.space[tmp_name]:create_index('I')\n            box.space[tmp_name]:create_index('I2',\n                                             {unique = false,\n                                              type='tree',\n                                              parts={{2, 'scalar',\n                                                      collation = c,\n                                                      is_nullable = true}}})\n            for i = 1, table.maxn(input_table) do\n                box.space[tmp_name]:insert{i, input_table[i]}\n            end\n            local t = box.space[tmp_name].index.I2:select()\n            for i = 1, table.maxn(input_table) do\n                input_table[i] = t[i][2]\n            end\n            box.space[tmp_name]:drop()\n          end\n```\n\n      For example, suppose table t = {1, 'A', -88.3, nil, true, 'b', 'B', nil, 'À'}.\n      After tarantool_sort(t, 'unicode_ci') t contains {nil, nil, true, -88.3, 1, 'A', 'À', 'b', 'B'}.",
          type = "function"
        },
        table = {
          description = "\nThe :code:`table` module has everything in the\n`standard Lua table library <https://www.lua.org/pil/19.html>`_,\nand some Tarantool extensions.\n\nYou can see this by saying \"table\": you will see this list of functions:\n``clear`` (LuaJIT extension = erase all elements),\n`concat <https://www.lua.org/manual/5.1/manual.html#pdf-table.concat>`_ (concatenate),\n``copy`` (make a copy of an array),\n``deepcopy`` (see description below),\n``foreach``,\n``foreach1``,\n`getn <https://www.lua.org/pil/19.1.html>`_ (get the number of elements in an array),\n`insert <https://www.lua.org/manual/5.1/manual.html#pdf-table.insert>`_ (insert an element into an array),\n`maxn <https://www.lua.org/manual/5.1/manual.html#pdf-table.maxn>`_ (get largest index)\n`move <https://www.lua.org/manual/5.3/manual.html#pdf-table.move>`_ (move elements between tables),\n``new`` (LuaJIT extension = return a new table with pre-allocated elements),\n`remove <https://www.lua.org/manual/5.1/manual.html#pdf-table.remove>`_ (remove an element from an array),\n`sort <https://www.lua.org/manual/5.1/manual.html#pdf-table.sort>`_ (sort the elements of an array).\n\nIn this section we only discuss the additional function\nthat the Tarantool developers have added: ``deepcopy``.\n\n.. _table-deepcopy:\n\n",
          type = "module"
        }
      },
      type = "table"
    }
  },
  type = "table"
}