return {
  fields = {
    tap = {
      fields = {
        est = {
          detail = "",
          type = "function"
        },
        tap = {
          description = "\n.. _tap-test:\n\n",
          type = "module"
        },
        test = {
          argsDisplay = "test-name",
          description = "Initialize.\n\n    The result of ``tap.test`` is an object, which will be called taptest\n    in the rest of this discussion, which is necessary for ``taptest:plan()``\n    and all the other methods.\n\n    :param string test-name: an arbitrary name to give for the test outputs.\n    :return: taptest\n    :rtype:  userdata\n\n    ```lua\n        tap = require('tap')\n        taptest = tap.test('test-name')\n```\n\n.. class:: taptest\n\n    .. _taptest-test:\n\n    .. method:: test(test-name, func)\n\n        Create a subtest (if no ``func`` argument specified), or\n        (if all arguments are specified)\n        create a subtest, run the test function and print the result.\n\n        See the `example`.\n\n        :param string name: an arbitrary name to give for the test outputs.\n        :param function fun: the test logic to run.\n        :return: taptest\n        :rtype:  userdata or string\n\n    .. _taptest-plan:\n\n    .. method:: plan(count)\n\n        Indicate how many tests will be performed.\n\n        :param number count:\n        :return: nil\n\n    .. _taptest-check:\n\n    .. method:: check()\n\n        Checks the number of tests performed.\n\n        The result will be a display saying ``# bad plan: ...`` if the number\n        of completed tests is not equal to the number of tests specified by\n        ``taptest:plan(...)``. (This is a purely Tarantool feature: \"bad plan\"\n        messages are out of the TAP13 standard.)\n\n        This check should only be done after all planned tests are complete,\n        so ordinarily ``taptest:check()`` will only appear at the end of a script.\n        However, as a Tarantool extension, ``taptest:check()`` may appear at the\n        end of any subtest. Therefore there are three ways to cause the check:\n\n        * by calling ``taptest:check()`` at the end of a script,\n        * by calling a function which ends with a call to ``taptest:check()``,\n        * or by calling taptest:test('...', subtest-function-name) where\n          subtest-function-name does not need to end with ``taptest:check()``\n          because it can be called after the subtest is complete.\n\n        :return: true or false.\n        :rtype:  boolean\n\n    .. _taptest-diag:\n\n    .. method:: diag(message)\n\n        Display a diagnostic message.\n\n        :param string message: the message to be displayed.\n        :return: nil\n\n    .. _taptest-ok:\n\n    .. method:: ok(condition, test-name)\n\n        This is a basic function which is used by other functions. Depending\n        on the value of ``condition``, print 'ok' or 'not ok' along with\n        debugging information. Displays the message.\n\n        :param boolean condition: an expression which is true or false\n        :param string  test-name: name of the test\n\n        :return: true or false.\n        :rtype:  boolean\n\n        **Example:**\n\n        ```lua\n            tarantool> taptest:ok(true, 'x')\n            ok - x\n            ---\n            - true\n            ...\n            tarantool> tap = require('tap')\n            ---\n            ...\n            tarantool> taptest = tap.test('test-name')\n            TAP version 13\n            ---\n            ...\n            tarantool> taptest:ok(1 + 1 == 2, 'X')\n            ok - X\n            ---\n            - true\n            ...\n```\n\n    .. _taptest-fail:\n\n    .. method:: fail(test-name)\n\n        ``taptest:fail('x')`` is equivalent to ``taptest:ok(false, 'x')``.\n        Displays the message.\n\n        :param string  test-name: name of the test\n\n        :return: true or false.\n        :rtype:  boolean\n\n    .. _taptest-skip:\n\n    .. method:: skip(message)\n\n        ``taptest:skip('x')`` is equivalent to\n        ``taptest:ok(true, 'x' .. '# skip')``.\n        Displays the message.\n\n        :param string  test-name: name of the test\n\n        :return: nil\n\n        **Example:**\n\n        ```lua\n            tarantool> taptest:skip('message')\n            ok - message # skip\n            ---\n            - true\n            ...\n```\n\n    .. _taptest-is:\n\n    .. method:: is(got, expected, test-name)\n\n        Check whether the first argument equals the second argument.\n        Displays extensive message if the result is false.\n\n        :param number got: actual result\n        :param number expected: expected result\n        :param string test-name: name of the test\n        :return: true or false.\n        :rtype:  boolean\n\n    .. _taptest-isnt:\n\n    .. method:: isnt(got, expected, test-name)\n\n        This is the negation of `taptest:is()`.\n\n        :param number got: actual result\n        :param number expected: expected result\n        :param string test-name: name of the test\n\n        :return: true or false.\n        :rtype:  boolean\n\n    .. _taptest-is_deeply:\n\n    .. method:: is_deeply(got, expected, test-name)\n\n        Recursive version of ``taptest:is(...)``, which can be be used to\n        compare tables as well as scalar values.\n\n        :return: true or false.\n        :rtype:  boolean\n\n        :param lua-value got: actual result\n        :param lua-value expected: expected result\n        :param string test-name: name of the test\n\n    .. _taptest-like:\n\n    .. method:: like(got, expected, test-name)\n\n        Verify a string against a\n        `pattern <http://lua-users.org/wiki/PatternsTutorial>`_.\n        Ok if match is found.\n\n        :return: true or false.\n        :rtype:  boolean\n\n        :param lua-value got: actual result\n        :param lua-value expected: pattern\n        :param string test-name: name of the test\n\n    ```lua\n        test:like(tarantool.version, '^[1-9]', \"version\")\n```\n\n    .. _taptest-unlike:\n\n    .. method:: unlike(got, expected, test-name)\n\n        This is the negation of `taptest:like()`.\n\n        :param number got: actual result\n        :param number expected: pattern\n        :param string test-name: name of the test\n\n        :return: true or false.\n        :rtype:  boolean\n\n    .. _taptest-istype:\n\n    .. method:: isnil(value, test-name)\n                isstring(value, test-name)\n                isnumber(value, test-name)\n                istable(value, test-name)\n                isboolean(value, test-name)\n                isudata(value, test-name)\n                iscdata(value, test-name)\n\n        Test whether a value has a particular type. Displays a long message if\n        the value is not of the specified type.\n\n        :param lua-value value:\n        :param string test-name: name of the test",
          detail = "Initialize",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}