return {
  fields = {
    utf8 = {
      fields = {
        casecmp = {
          argsDisplay = "UTF8-string, utf8-string",
          description = ":param UTF8-string string: a string encoded with UTF-8\n    :return: -1 meaning \"less\", 0 meaning \"equal\", +1 meaning \"greater\"\n    :rtype: number\n\n    Compare two strings with the Default Unicode Collation Element Table\n    (DUCET) for the\n    `Unicode Collation Algorithm <http://www.unicode.org/Public/UCA/10.0.0/allkeys.txt>`_.\n    Thus 'å' is less than 'B', even though the code-point value of å (229) is greater\n    than the code-point value of B (66), because the algorithm depends on\n    the values in the Collation Element Table, not the code-point values.\n\n    The comparison is done with primary weights. Therefore the\n    elements which affect secondary or later weights (such as \"case\"\n    in Latin or Cyrillic alphabets, or \"kana differentiation\" in Japanese)\n    are ignored. If asked \"is this like a Microsoft case-insensitive\n    accent-insensitive collation\" we tend to answer \"yes\", though the\n    Unicode Collation Algorithm is far more sophisticated than those\n    terms imply.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.casecmp('é','e'),utf8.casecmp('E','e')\n        ---\n        - 0\n        - 0\n        ...\n```\n\n.. _utf8-char:\n\n.",
          type = "function"
        },
        char = {
          argsDisplay = "code-point [, code-point ...]",
          description = ":param code-point number: a Unicode code point value, repeatable\n    :return: a UTF-8 string\n    :rtype: string\n\n    The code-point number is the value that corresponds to a character\n    in the\n    `Unicode Character Database <http://www.unicode.org/Public/5.2.0/ucd/UnicodeData.txt>`_\n    This is not the same as the byte values of the encoded character,\n    because the UTF-8 encoding scheme is more complex than a simple\n    copy of the code-point number.\n\n    Another way to construct a string with Unicode characters is\n    with the \\\\u{hex-digits} escape mechanism, for example\n    '\\\\u{41}\\\\u{42}' and ``utf8.char(65,66)`` both produce the string 'AB'.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.char(229)\n        ---\n        - å\n        ...\n```\n\n.. _utf8-cmp:\n\n.",
          type = "function"
        },
        cmp = {
          argsDisplay = "UTF8-string, utf8-string",
          description = ":param UTF8-string string: a string encoded with UTF-8\n    :return: -1 meaning \"less\", 0 meaning \"equal\", +1 meaning \"greater\"\n    :rtype: number\n\n    Compare two strings with the Default Unicode Collation Element Table\n    (DUCET) for the\n    `Unicode Collation Algorithm <http://www.unicode.org/Public/UCA/10.0.0/allkeys.txt>`_.\n    Thus 'å' is less than 'B', even though the code-point value of å (229) is greater\n    than the code-point value of B (66), because the algorithm depends on\n    the values in the Collation Element Table, not the code values.\n\n    The comparison is done with at least three weights. Therefore the\n    elements which affect secondary or later weights (such as \"case\"\n    in Latin or Cyrillic alphabets, or \"kana differentiation\" in Japanese)\n    are not ignored. and upper case comes after lower case.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.cmp('é','e'),utf8.cmp('E','e')\n        ---\n        - 1\n        - 1\n        ...\n```\n\n.. _utf8-isalpha:\n\n.",
          type = "function"
        },
        isalpha = {
          argsDisplay = "UTF8-character",
          description = ":param UTF8-character string-or-number: a single UTF8 character, expressed\n                                            as a one-byte string or a code point value\n    :return: true or false\n    :rtype: boolean\n\n    Return true if the input character is an \"alphabetic-like\" character, otherwise return false.\n    Generally speaking a character will be considered alphabetic-like provided it\n    is typically used within a word, as opposed to a digit or punctuation.\n    It does not have to be a character in an alphabet.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.isalpha('Ж'),utf8.isalpha('å'),utf8.isalpha('9')\n        ---\n        - true\n        - true\n        - false\n        ...\n```\n\n.. _utf8-isdigit:\n\n.",
          type = "function"
        },
        isdigit = {
          argsDisplay = "UTF8-character",
          description = ":param UTF8-character string-or-number: a single UTF8 character, expressed as a one-byte\n                                            string or a code point value\n    :return: true or false\n    :rtype: boolean\n\n    Return true if the input character is a digit, otherwise return false.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.isdigit('Ж'),utf8.isdigit('å'),utf8.isdigit('9')\n        ---\n        - false\n        - false\n        - true\n        ...\n```\n\n.. _utf8-islower:\n\n.",
          type = "function"
        },
        islower = {
          argsDisplay = "UTF8-character",
          description = ":param UTF8-character string-or-number: a single UTF8 character, expressed as a one-byte\n                                            string or a code point value\n    :return: true or false\n    :rtype: boolean\n\n    Return true if the input character is lower case, otherwise return false.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.islower('Ж'),utf8.islower('å'),utf8.islower('9')\n        ---\n        - false\n        - true\n        - false\n        ...\n```\n\n.. _utf8-isupper:\n\n.",
          type = "function"
        },
        isupper = {
          argsDisplay = "UTF8-character",
          description = ":param UTF8-character string-or-number: a single UTF8 character, expressed as a one-byte string\n                                            or a code point value\n    :return: true or false\n    :rtype: boolean\n\n    Return true if the input character is upper case, otherwise return false.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.isupper('Ж'),utf8.isupper('å'),utf8.isupper('9')\n        ---\n        - true\n        - false\n        - false\n        ...\n```\n\n.. _utf8-length:\n\n.",
          type = "function"
        },
        length = {
          argsDisplay = "UTF8-string [, start-byte [, end-byte]]",
          description = ":param UTF8-string string: a string encoded with UTF-8\n    :param start-byte integer: byte position of the first character\n    :param end-byte integer: byte position where to stop\n    :return: the number of characters in the string, or between start and end\n    :rtype: number\n\n    Byte positions for start and end can be negative, which indicates\n    \"calculate from end of string\" rather than \"calculate from start of string\".\n\n    If the string contains a byte sequence which is not valid in UTF-8,\n    each byte in the invalid byte sequence will be counted as one character.\n\n    UTF-8 is a variable-size encoding scheme. Typically\n    a simple Latin letter takes one byte, a Cyrillic letter\n    takes two bytes, a Chinese/Japanese character takes three\n    bytes, and the maximum is four bytes.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.len('G'),utf8.len('ж')\n        ---\n        - 1\n        - 1\n        ...\n```\n\n        tarantool> string.len('G'),string.len('ж')\n        ---\n        - 1\n        - 2\n        ...\n\n.. _utf8-lower:\n\n.",
          type = "function"
        },
        lower = {
          argsDisplay = "UTF8-string",
          description = ":param UTF8-string string: a string encoded with UTF-8\n    :return: the same string, lower case\n    :rtype: string\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.lower('ÅΓÞЖABCDEFG')\n        ---\n        - åγþжabcdefg\n        ...\n```\n\n.. _utf8-next:\n\n.",
          type = "function"
        },
        next = {
          argsDisplay = "UTF8-string [, start-byte]",
          description = ":param UTF8-string string: a string encoded with UTF-8\n    :param start-byte integer: byte position where to start within the string, default is 1\n    :return: byte position of the next character and the code point value of the next character\n    :rtype: table\n\n    The ``next`` function is often used in a loop to get one character\n    at a time from a UTF-8 string.\n\n    **Example:**\n\n    In the string 'åa' the first character is 'å', it starts\n    at position 1, it takes two bytes to store so the\n    character after it will be at position 3, its Unicode\n    code point value is (decimal) 229.\n\n    ```lua\n        tarantool> -- show next-character position + first-character codepoint\n        tarantool> utf8.next('åa', 1)\n        ---\n        - 3\n        - 229\n        ...\n        tarantool> -- (loop) show codepoint of every character\n        tarantool> for position,codepoint in utf8.next,'åa' do print(codepoint) end\n        229\n        97\n        ...\n```\n\n.. _utf8-sub:\n\n.",
          type = "function"
        },
        sub = {
          argsDisplay = "UTF8-string, start-character [, end-character]",
          description = ":param UTF8-string string: a string encoded as UTF-8\n    :param start-character number: the position of the first character\n    :param end-character number: the position of the last character\n    :return: a UTF-8 string, the \"substring\" of the input value\n    :rtype: string\n\n    Character positions for start and end can be negative, which indicates\n    \"calculate from end of string\" rather than \"calculate from start of string\".\n\n    The default value\n    for end-character is the length of the input string. Therefore, saying\n    ``utf8.sub(1, 'abc')`` will return 'abc', the same as the input string.\n\n    **Example:**\n\n    ```lua\n        tarantool> utf8.sub('åγþжabcdefg', 5, 8)\n        ---\n        - abcd\n        ...\n```\n\n.. _utf8-upper:\n\n.",
          type = "function"
        },
        upper = {
          argsDisplay = "UTF8-string",
          description = ":param UTF8-string string: a string encoded with UTF-8\n    :return: the same string, upper case\n    :rtype: string\n\n    .. NOTE::\n\n        In rare cases the upper-case result may be longer\n        than the lower-case input, for example ``utf8.upper('ß')`` is 'SS'.\n\n    **Example:**\n\n    .. code-block:: tarantoolsession\n\n        tarantool> utf8.upper('åγþжabcdefg')\n        ---\n        - ÅΓÞЖABCDEFG\n        ...",
          type = "function"
        },
        utf8 = {
          description = "\n.. _utf8-casecmp:\n\n",
          type = "module"
        }
      },
      type = "table"
    }
  },
  type = "table"
}