return {
  fields = {
    http = {
      fields = {
        client_object = {
          detail = "Get a table with statistics",
          type = "function"
        },
        ["http.client"] = {
          description = "\n===============================================================================\n                                   Overview\n===============================================================================\n\nThe ``http`` module, specifically the ``http.client`` submodule,\nprovides the functionality of an HTTP client with support for HTTPS and keepalive.\nIt uses routines in the `libcurl <https://curl.haxx.se/libcurl/>`_ library.\n\n===============================================================================\n                                    Index\n===============================================================================\n\nBelow is a list of all ``http`` functions.\n\n.. container:: table\n\n    .. rst-class:: left-align-column-1\n    .. rst-class:: left-align-column-2\n\n    +--------------------------------------+---------------------------------+\n    | Name                                 | Use                             |\n    +======================================+=================================+\n    | `http.client.new()              | Create an HTTP client instance  |\n    |`                          |                                 |\n    +--------------------------------------+---------------------------------+\n    | `client_object:request()        | Perform an HTTP request         |\n    |`             |                                 |\n    +--------------------------------------+---------------------------------+\n    | `client_object:stat()           | Get a table with statistics     |\n    |`                |                                 |\n    +--------------------------------------+---------------------------------+\n\n.. _http-new:\n\n",
          type = "module"
        },
        new = {
          argsDisplay = "[options]",
          description = "Construct a new HTTP client instance.\n\n    :param table options: integer settings which are passed to ``libcurl``.\n\n    The two possible options are ``max_connections`` and ``max_total_connections``.\n\n    ``max_connections`` is the maximum number of entries in the cache.\n    It affects ``libcurl``'s `CURLMOPT_MAXCONNECTS <https://curl.haxx.se/libcurl/c/CURLMOPT_MAXCONNECTS.html>`_.\n    The default is -1.\n\n    ``max_total_connections`` is the maximum number of active connections.\n    It affects ``libcurl``'s  `CURLMOPT_MAX_TOTAL_CONNECTIONS <https://curl.haxx.se/libcurl/c/CURLMOPT_MAX_TOTAL_CONNECTIONS.html>`_.\n    It is ignored if the ``curl`` version is less than 7.30.\n    The default is 0, which allows ``libcurl`` to scale according to easy handles count.\n\n    The default option values are usually good enough but in rare cases it\n    might be good to set them. In that case here are two tips.\n\n    1. You may want to control the maximum number of sockets that a particular http client uses simultaneously.\n    If a system passes many requests to distinct hosts, then ``libcurl`` cannot reuse sockets.\n    In this case setting ``max_total_connections`` may be useful,\n    since it causes ``curl`` to avoid creating too many sockets which would not be used anyway.\n\n    2. Do not set ``max_connections`` less than ``max_total_connections``\n    unless you are confident about your actions.\n    When ``max_connections`` is less then ``max_total_connections``, in some cases\n    ``libcurl`` will not reuse sockets for requests that are going to the same host.\n    If the limit is reached and a new request occurs, then\n    ``libcurl`` will first create a new socket, send the request, wait for the first connection\n    to be free, and close it, in order to avoid exceeding the ``max_connections`` cache size.\n    In the worst case, ``libcurl`` will create a new socket for every request,\n    even if all requests are going to the same host.\n    See `this Tarantool issue on github <https://github.com/tarantool/tarantool/issues/3945>`_\n    for details.\n\n    :return: a new HTTP client instance\n    :rtype:  userdata\n\n    **Example:**\n\n    ```lua\n        tarantool> http_client = require('http.client').new({max_connections = 5})\n        ---\n        ...\n```\n\n.. class:: client_object\n\n    .. _client_object-request:\n\n    .. method:: request(method, url, body, opts)\n\n        If ``http_client`` is an HTTP client instance, ``http_client:request()`` will\n        perform an HTTP request and, if there is a successful connection,\n        will return a table with connection information.\n\n        :param string method: HTTP method, for example 'GET' or 'POST' or 'PUT'\n        :param string url: location, for example 'https://tarantool.org/doc'\n        :param string body: optional initial message, for example 'My text string!'\n        :param table opts: table of connection options, with any of these\n         components:\n\n          * ``timeout`` - number of seconds to wait for a ``curl`` API read request\n            before timing out\n          * ``ca_path`` - path to a directory holding one or more certificates to\n            verify the peer with\n          * ``ca_file`` - path to an SSL certificate file to verify the peer with\n          * ``verify_host`` - set on/off verification of the certificate's name\n            (CN) against host. See also\n            `CURLOPT_SSL_VERIFYHOST <https://curl.haxx.se/libcurl/c/CURLOPT_SSL_VERIFYHOST.html>`_\n          * ``verify_peer`` - set on/off verification of the peer's SSL\n            certificate. See also\n            `CURLOPT_SSL_VERIFYPEER <https://curl.haxx.se/libcurl/c/CURLOPT_SSL_VERIFYPEER.html>`_\n          * ``ssl_key`` - path to a private key file for a TLS and SSL client\n            certificate. See also\n            `CURLOPT_SSLKEY <https://curl.haxx.se/libcurl/c/CURLOPT_SSLKEY.html>`_\n          * ``ssl_cert`` - path to a SSL client certificate file. See also\n            `CURLOPT_SSLCERT <https://curl.haxx.se/libcurl/c/CURLOPT_SSLCERT.html>`_\n          * ``headers`` - table of HTTP headers\n          * ``keepalive_idle`` - delay, in seconds, that the operating system\n            will wait while the connection is idle before sending keepalive\n            probes. See also\n            `CURLOPT_TCP_KEEPIDLE <https://curl.haxx.se/libcurl/c/CURLOPT_TCP_KEEPIDLE.html>`_\n            and the note below about keepalive_interval.\n          * ``keepalive_interval`` - the interval, in seconds, that the operating\n            system will wait between sending keepalive probes. See also\n            `CURLOPT_TCP_KEEPINTVL <https://curl.haxx.se/libcurl/c/CURLOPT_TCP_KEEPINTVL.html>`_.\n            If both keepalive_idle and keepalive_interval are set, then\n            Tarantool will also set HTTP keepalive headers: Connection:Keep-Alive\n            and Keep-Alive:timeout=<keepalive_idle>.\n            Otherwise Tarantool will send Connection:close\n          * ``low_speed_time`` - set the \"low speed time\" -- the time that the\n            transfer speed should be below the \"low speed limit\" for the library\n            to consider it too slow and abort. See also\n            `CURLOPT_LOW_SPEED_TIME <https://curl.haxx.se/libcurl/c/CURLOPT_LOW_SPEED_TIME.html>`_\n          * ``low_speed_limit`` - set the \"low speed limit\" -- the average\n            transfer speed in bytes per second that the transfer should be below\n            during \"low speed time\" seconds for the library to consider it to be\n            too slow and abort. See also\n            `CURLOPT_LOW_SPEED_LIMIT <https://curl.haxx.se/libcurl/c/CURLOPT_LOW_SPEED_LIMIT.html>`_\n          * ``verbose`` - set on/off verbose mode\n          * ``unix_socket`` - a socket name to use instead of an Internet address,\n            for a local connection. The Tarantool server must be built with\n            ``libcurl`` 7.40 or later. See the `second example`\n            later in this section.\n          * ``max_header_name_len`` - the maximal length of a header name. If a header\n            name is bigger than this value, it is truncated to this length.\n            The default value is '32'.\n\n        :return: response information, with all of these components:\n\n          * ``status`` - HTTP response status\n          * ``reason`` - HTTP response status text\n          * ``headers`` - a Lua table with normalized HTTP headers\n          * ``body`` - response body\n          * ``proto`` - protocol version\n          * ``cookies`` - a Lua table with response cookies and their options",
          detail = "Create an HTTP client instance",
          type = "function"
        },
        stat = {
          argsDisplay = "",
          description = "The ``http_client:stat()`` function returns a table with statistics:\n\n        * ``active_requests`` - number of currently executing requests\n        * ``sockets_added`` - total number of sockets added into an event loop\n        * ``sockets_deleted`` - total number of sockets sockets from an event loop\n        * ``total_requests`` - total number of requests\n        * ``http_200_responses`` - total number of requests which have returned\n          code HTTP 200\n        * ``http_other_responses`` - total number of requests which have not\n          returned code HTTP 200\n        * ``failed_requests`` - total number of requests which have failed\n          including system errors, ``curl`` errors, and HTTP errors\n\n.. _http-example1:\n\n**Example 1:**\n\nConnect to an HTTP server, look at the size of the response for a 'GET' request,\nand look at the statistics for the session.\n\n```lua\n    tarantool> http_client = require('http.client').new()\n    ---\n    ...\n    tarantool> r = http_client:request('GET','http://tarantool.org')\n    ---\n    ...\n    tarantool> string.len(r.body)\n    ---\n    - 21725\n    ...\n    tarantool> http_client:stat()\n    ---\n    - total_requests: 1\n      sockets_deleted: 2\n      failed_requests: 0\n      active_requests: 0\n      http_other_responses: 0\n      http_200_responses: 1\n      sockets_added: 2\n```\n\n.. _http-example2:\n\n**Example 2:**\n\nStart two Tarantool instances on the same computer.\n\nOn the first Tarantool instance, listen on a Unix socket:\n\n```lua\n    box.cfg{listen='/tmp/unix_domain_socket.sock'}\n```\n\nOn the second Tarantool instance, send via ``http_client``:\n\n```lua\n    box.cfg{}\n    http_client = require('http.client').new({5})\n    http_client:put('http://localhost/','body',{unix_socket = '/tmp/unix_domain_socket.sock'})\n```\n\nTerminal #1 will show an error message: \"Invalid MsgPack\".\nThis is not useful but demonstrates the syntax and demonstrates\nthat was sent was received.",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}